==> create-tpl-1.0.0.tgz: package/create.js <==
/**
 * @author 翁旺
 * @date 2018-09-19 16:01:40
 * @description 自动生成前端项目脚手架脚本
 * @email wengwang@cecdat.com
 * @copyright Copyright 2018 CEC(Fujian) Healthcare Big Data Operation Service Co., Ltd. All rights reserved.
 */
const commander = require('commander')
const pkg = require('./package.json')
const path = require('path')
const fs = require('fs-extra')
const chalk = require('chalk')
const spawn = require('cross-spawn')
const download = require('download-git-repo')

let projectName

// 使用master分支的zip
const zipURL = 'http://192.168.1.23:8888/cecdataFE/vue-boilerplate/-/archive/master/vue-boilerplate-master.zip'

new commander
  .Command(pkg.name)
  .version(pkg.version)
  .action(name => {
    projectName = name
  })
  .parse(process.argv)

if (!projectName) {
  console.log(chalk.red('必须填写项目名称,例如 create-tpl project'))
  process.exit(1)
}

const commond = 'npm'
const commondArgs = ['install']

if (!fs.ensureDirSync(path.resolve(projectName))) {
  fs.mkdirsSync(path.resolve(projectName))
  console.log(chalk.green(`创建 ${projectName} 文件夹成功`))
}
const appDir = path.resolve(projectName)

download(`direct:${zipURL}`, appDir, function (err) {
  if (err) {
    chalk.red('下载压缩包出错...')
    return false
  }
  console.log(chalk.green(`生成模板文件成功`))
  process.chdir(appDir)

  console.log(chalk.yellow(`正在安装依赖 ...`))
  spawn.sync(commond, ['install', '-g', 'commitlint'], { stdio: 'inherit' })
  spawn.sync(commond, commondArgs, { stdio: 'inherit' })
  console.log(chalk.green(`安装依赖成功`))

  console.log('\n')

  console.log(chalk.green(`执行以下命令就能愉快的开始了：`))
  console.log(chalk.cyan(`cd ./${projectName} && npm run dev`))
})

==> create-tpl-1.0.1.tgz: package/create.js <==
/**
 * @author 翁旺
 * @date 2018-09-19 16:01:40
 * @description 自动生成前端项目脚手架脚本
 * @email wengwang@cecdat.com
 * @copyright Copyright 2018 CEC(Fujian) Healthcare Big Data Operation Service Co., Ltd. All rights reserved.
 */
const commander = require('commander')
const pkg = require('./package.json')
const path = require('path')
const fs = require('fs-extra')
const chalk = require('chalk')
const spawn = require('cross-spawn')
const download = require('download-git-repo')

let projectName

// 使用master分支的zip
const zipURL = 'http://192.168.1.23:8888/cecdataFE/react-boilerplate/-/archive/master/react-boilerplate-master.zip'

new commander
  .Command(pkg.name)
  .version(pkg.version)
  .action(name => {
    projectName = name
  })
  .parse(process.argv)

if (!projectName) {
  console.log(chalk.red('必须填写项目名称,例如 create-tpl project'))
  process.exit(1)
}

const commond = 'npm'
const commondArgs = ['install']

if (!fs.ensureDirSync(path.resolve(projectName))) {
  fs.mkdirsSync(path.resolve(projectName))
  console.log(chalk.green(`创建 ${projectName} 文件夹成功`))
}
const appDir = path.resolve(projectName)

download(`direct:${zipURL}`, appDir, function (err) {
  if (err) {
    chalk.red('下载压缩包出错...')
    return false
  }
  console.log(chalk.green(`生成模板文件成功`))
  process.chdir(appDir)

  console.log(chalk.yellow(`正在安装依赖 ...`))
  spawn.sync(commond, ['install', '-g', 'commitlint'], { stdio: 'inherit' })
  spawn.sync(commond, commondArgs, { stdio: 'inherit' })
  console.log(chalk.green(`安装依赖成功`))

  console.log('\n')

  console.log(chalk.green(`执行以下命令就能愉快的开始了：`))
  console.log(chalk.cyan(`cd ./${projectName} && npm run dev`))
})
